@@ -5,20 +5,21 @@
 # --------------------------------------------------------------------------
 # pylint: disable=invalid-overridden-method
 from typing import (  # pylint: disable=unused-import
-    Union, Optional, Any, IO, Iterable, AnyStr, Dict, List, Tuple,
+    Optional, Any, IO, Iterable, AnyStr, Dict, List, Tuple,
     TypeVar, TYPE_CHECKING
 )
 
+from azure.core.exceptions import HttpResponseError
 from azure.core.tracing.decorator_async import distributed_trace_async
 
 from .._shared.response_handlers import return_response_headers, process_storage_error
-from .._generated.models import (
-    StorageErrorException)
+from .._generated.aio.operations import FileOperations, ShareOperations
 from .._lease import ShareLeaseClient as LeaseClientBase
 
 if TYPE_CHECKING:
     from datetime import datetime
     ShareFileClient = TypeVar("ShareFileClient")
+    ShareClient = TypeVar("ShareClient")
 
 
 class ShareLeaseClient(LeaseClientBase):
@@ -38,7 +39,7 @@ class ShareLeaseClient(LeaseClientBase):
 
     :param client:
         The client of the file to lease.
-    :type client: ~azure.storage.fileshare.aio.ShareFileClient
+    :type client: ~azure.storage.fileshare.ShareFileClient
     :param str lease_id:
         A string representing the lease ID of an existing lease. This value does not
         need to be specified in order to acquire a new lease, or break one.
@@ -58,7 +59,7 @@ class ShareLeaseClient(LeaseClientBase):
 
     @distributed_trace_async
     async def acquire(self, **kwargs):
-        # type: (int, Any) -> None
+        # type: (**Any) -> None
         """Requests a new lease. This operation establishes and manages a lock on a
         file for write and delete operations. If the file does not have an active lease,
         the File service creates a lease on the file. If the file has an active lease,
@@ -73,41 +74,73 @@ class ShareLeaseClient(LeaseClientBase):
         :rtype: None
         """
         try:
+            lease_duration = kwargs.pop('lease_duration', -1)
+            if self._snapshot:
+                kwargs['sharesnapshot'] = self._snapshot
             response = await self._client.acquire_lease(
                 timeout=kwargs.pop('timeout', None),
-                duration=-1,
+                duration=lease_duration,
                 proposed_lease_id=self.id,
                 cls=return_response_headers,
                 **kwargs)
-        except StorageErrorException as error:
+        except HttpResponseError as error:
             process_storage_error(error)
         self.id = response.get('lease_id')  # type: str
         self.last_modified = response.get('last_modified')   # type: datetime
         self.etag = response.get('etag')  # type: str
 
+    @distributed_trace_async
+    async def _renew(self, **kwargs):
+        # type: (Any) -> None
+        """Renews the share lease.
+
+        The share lease can be renewed if the lease ID specified in the
+        lease client matches that associated with the share. Note that
+        the lease may be renewed even if it has expired as long as the share
+        has not been leased again since the expiration of that lease. When you
+        renew a lease, the lease duration clock resets.
+
+        .. versionadded:: 12.6.0
+
+        :keyword int timeout:
+            The timeout parameter is expressed in seconds.
+        :return: None
+        """
+        if isinstance(self._client, FileOperations):
+            raise TypeError("Lease renewal operations are only valid for ShareClient.")
+        try:
+            response = await self._client.renew_lease(
+                lease_id=self.id,
+                timeout=kwargs.pop('timeout', None),
+                sharesnapshot=self._snapshot,
+                cls=return_response_headers,
+                **kwargs)
+        except HttpResponseError as error:
+            process_storage_error(error)
+        self.etag = response.get('etag')  # type: str
+        self.id = response.get('lease_id')  # type: str
+        self.last_modified = response.get('last_modified')   # type: datetime
+
     @distributed_trace_async
     async def release(self, **kwargs):
         # type: (Any) -> None
         """Releases the lease. The lease may be released if the lease ID specified on the request matches
-        that associated with the file. Releasing the lease allows another client to immediately acquire the lease
-        for the file as soon as the release is complete.
-
-
-        The lease may be released if the client lease id specified matches
-        that associated with the file. Releasing the lease allows another client
-        to immediately acquire the lease for the file as soon as the release is complete.
+        that associated with the file. Releasing the lease allows another client to immediately acquire
+        the lease for the file as soon as the release is complete.
 
         :keyword int timeout:
             The timeout parameter is expressed in seconds.
         :return: None
         """
         try:
+            if self._snapshot:
+                kwargs['sharesnapshot'] = self._snapshot
             response = await self._client.release_lease(
                 lease_id=self.id,
                 timeout=kwargs.pop('timeout', None),
                 cls=return_response_headers,
                 **kwargs)
-        except StorageErrorException as error:
+        except HttpResponseError as error:
             process_storage_error(error)
         self.etag = response.get('etag')  # type: str
         self.id = response.get('lease_id')  # type: str
@@ -119,22 +152,23 @@ class ShareLeaseClient(LeaseClientBase):
         """ Changes the lease ID of an active lease. A change must include the current lease ID in x-ms-lease-id and
         a new lease ID in x-ms-proposed-lease-id.
 
-
         :param str proposed_lease_id:
-            Proposed lease ID, in a GUID string format. The File service returns 400
+            Proposed lease ID, in a GUID string format. The File service raises an error
             (Invalid request) if the proposed lease ID is not in the correct format.
         :keyword int timeout:
             The timeout parameter is expressed in seconds.
         :return: None
         """
         try:
+            if self._snapshot:
+                kwargs['sharesnapshot'] = self._snapshot
             response = await self._client.change_lease(
                 lease_id=self.id,
                 proposed_lease_id=proposed_lease_id,
                 timeout=kwargs.pop('timeout', None),
                 cls=return_response_headers,
                 **kwargs)
-        except StorageErrorException as error:
+        except HttpResponseError as error:
             process_storage_error(error)
         self.etag = response.get('etag')  # type: str
         self.id = response.get('lease_id')  # type: str
@@ -142,7 +176,7 @@ class ShareLeaseClient(LeaseClientBase):
 
     @distributed_trace_async
     async def break_lease(self, **kwargs):
-        # type: (Optional[int], Any) -> int
+        # type: (Any) -> int
         """Force breaks the lease if the file has an active lease. Any authorized request can break the lease;
         the request is not required to specify a matching lease ID. An infinite lease breaks immediately.
 
@@ -157,10 +191,18 @@ class ShareLeaseClient(LeaseClientBase):
         :rtype: int
         """
         try:
+            lease_break_period = kwargs.pop('lease_break_period', None)
+            if self._snapshot:
+                kwargs['sharesnapshot'] = self._snapshot
+            if isinstance(self._client, ShareOperations):
+                kwargs['break_period'] = lease_break_period
+            if isinstance(self._client, FileOperations) and lease_break_period:
+                raise TypeError("Setting a lease break period is only applicable to Share leases.")
+
             response = await self._client.break_lease(
                 timeout=kwargs.pop('timeout', None),
                 cls=return_response_headers,
                 **kwargs)
-        except StorageErrorException as error:
+        except HttpResponseError as error:
             process_storage_error(error)
         return response.get('lease_time') # type: ignore
